@@ -19,7 +19,7 @@ mardia <- function(data, cov = TRUE, tol = 1e-25){
   g1p <- sum(D^3)/n^2
   g2p <- sum(diag((D^2)))/n
   df <- p * (p + 1) * (p + 2)/6
-  k = ((p + 1)*(n + 1)*(n + 3))/(n*(n + 1)*(p + 1) - 6)
+  k = ((p + 1)*(n + 1)*(n + 3))/(n*((n + 1)*(p + 1) - 6))
 
   if(n < 20){
 
